==> rc-ui-lib-0.1.35.tgz: package/es/skeleton/Skeleton.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["children", "className", "style"];
import React, { useContext } from 'react';
import cls from 'classnames';
import { addUnit, getSizeStyle } from '../utils';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var DEFAULT_ROW_WIDTH = '100%';
var DEFAULT_LAST_ROW_WIDTH = '60%';

var Skeleton = function Skeleton(_ref) {
  var children = _ref.children,
      className = _ref.className,
      style = _ref.style,
      props = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('skeleton', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var getRowWidth = function getRowWidth(index) {
    var rowWidth = props.rowWidth;

    if (rowWidth === DEFAULT_ROW_WIDTH && index === +props.row - 1) {
      return DEFAULT_LAST_ROW_WIDTH;
    }

    if (Array.isArray(rowWidth)) {
      return rowWidth[index];
    }

    return rowWidth;
  };

  var getRowHeight = function getRowHeight(index) {
    var rowHeight = props.rowHeight;

    if (Array.isArray(rowHeight)) {
      return rowHeight[index];
    }

    return rowHeight;
  };

  var renderAvatar = function renderAvatar() {
    if (props.avatar) {
      return /*#__PURE__*/React.createElement("div", {
        className: cls(bem('avatar', props.avatarShape)),
        style: getSizeStyle(props.avatarSize)
      });
    }

    return null;
  };

  var renderTitle = function renderTitle() {
    if (props.title) {
      var width = addUnit(props.titleWidth);
      var height = addUnit(getRowHeight(0));
      return /*#__PURE__*/React.createElement("div", {
        className: cls(bem('title')),
        style: {
          width: width,
          height: height
        }
      });
    }

    return null;
  };

  var renderRows = function renderRows() {
    return Array(props.row).fill('').map(function (_, i) {
      var width = addUnit(getRowWidth(i));
      var height = addUnit(getRowHeight(i)); // eslint-disable-next-line react/no-array-index-key

      return /*#__PURE__*/React.createElement("div", {
        key: i,
        className: cls(bem('row')),
        style: {
          width: width,
          height: height
        }
      });
    });
  };

  if (!props.loading) return children;
  return /*#__PURE__*/React.createElement("div", {
    className: cls(className, bem({
      animate: props.animate,
      round: props.round
    })),
    style: style
  }, renderAvatar(), /*#__PURE__*/React.createElement("div", {
    className: cls(bem('content'))
  }, renderTitle(), renderRows()));
};

Skeleton.defaultProps = {
  loading: true,
  animate: true,
  round: true,
  row: 3,
  avatarShape: 'round',
  rowWidth: DEFAULT_ROW_WIDTH
};
export default Skeleton;

==> rc-ui-lib-1.3.4.tgz: package/es/skeleton/Skeleton.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["children", "className", "style"];
import React, { useContext } from 'react';
import classnames from 'classnames';
import { addUnit, getSizeStyle } from '../utils';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
var DEFAULT_ROW_WIDTH = '100%';
var DEFAULT_LAST_ROW_WIDTH = '60%';

var Skeleton = function Skeleton(_ref) {
  var children = _ref.children,
      className = _ref.className,
      style = _ref.style,
      props = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('skeleton', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var getRowWidth = function getRowWidth(index) {
    var rowWidth = props.rowWidth;

    if (rowWidth === DEFAULT_ROW_WIDTH && index === +props.row - 1) {
      return DEFAULT_LAST_ROW_WIDTH;
    }

    if (Array.isArray(rowWidth)) {
      return rowWidth[index];
    }

    return rowWidth;
  };

  var getRowHeight = function getRowHeight(index) {
    var rowHeight = props.rowHeight;

    if (Array.isArray(rowHeight)) {
      return rowHeight[index];
    }

    return rowHeight;
  };

  var renderAvatar = function renderAvatar() {
    if (props.avatar) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('avatar', props.avatarShape)),
        style: getSizeStyle(props.avatarSize)
      });
    }

    return null;
  };

  var renderTitle = function renderTitle() {
    if (props.title) {
      var width = addUnit(props.titleWidth);
      var height = addUnit(getRowHeight(0));
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('title')),
        style: {
          width: width,
          height: height
        }
      });
    }

    return null;
  };

  var renderRows = function renderRows() {
    return Array(props.row).fill('').map(function (_, i) {
      var width = addUnit(getRowWidth(i));
      var height = addUnit(getRowHeight(i)); // eslint-disable-next-line react/no-array-index-key

      return /*#__PURE__*/React.createElement("div", {
        key: i,
        className: classnames(bem('row')),
        style: {
          width: width,
          height: height
        }
      });
    });
  };

  if (!props.loading) return children;
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(className, bem({
      animate: props.animate,
      round: props.round
    })),
    style: style
  }, renderAvatar(), /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('content'))
  }, renderTitle(), renderRows()));
};

Skeleton.defaultProps = {
  loading: true,
  animate: true,
  round: true,
  row: 3,
  avatarShape: 'round',
  rowWidth: DEFAULT_ROW_WIDTH
};
export default Skeleton;
